@@ -380,9 +380,10 @@ oauth2_cfg_endpoint_auth_basic_options_set(oauth2_log_t *log,
 	return rv;
 }
 
-typedef char *(oauth2_cfg_endpoint_auth_set_options_cb_t)(
-    oauth2_log_t *log, oauth2_cfg_endpoint_auth_t *auth,
-    const oauth2_nv_list_t *params);
+typedef char *(
+    oauth2_cfg_endpoint_auth_set_options_cb_t)(oauth2_log_t *log,
+					       oauth2_cfg_endpoint_auth_t *auth,
+					       const oauth2_nv_list_t *params);
 
 typedef struct oauth2_cfg_endpoint_auth_set_options_ctx_t {
 	const char *type;
