@@ -1278,7 +1278,7 @@ bool oauth2_jose_jwt_verify(oauth2_log_t *log,
 
 	jws = cjose_jws_import(token, strlen(token), &err);
 	if (jws == NULL) {
-		oauth2_error(log, "cjose_jws_import failed: %s", err.message);
+		_OAUTH2_UTIL_JOSE_ERR_LOG(log, "cjose_jws_import", err);
 		goto end;
 	}
 
@@ -1317,8 +1317,7 @@ bool oauth2_jose_jwt_verify(oauth2_log_t *log,
 
 	if (cjose_jws_get_plaintext(jws, &plaintext, &plaintext_len, &err) ==
 	    false) {
-		oauth2_error(log, "cjose_jws_get_plaintext failed: %s",
-			     err.message);
+		_OAUTH2_UTIL_JOSE_ERR_LOG(log, "cjose_jws_get_plaintext", err);
 		goto end;
 	}
 
@@ -1851,8 +1850,9 @@ static oauth2_jose_jwk_list_t *oauth2_jose_jwks_list_resolve(
 	return oauth2_jose_jwk_list_clone(log, provider->jwks);
 }
 
-typedef oauth2_jose_jwk_list_t *(oauth2_jose_jwks_url_resolve_response_cb_t)(
-    oauth2_log_t *log, char *response);
+typedef oauth2_jose_jwk_list_t *(
+    oauth2_jose_jwks_url_resolve_response_cb_t)(oauth2_log_t *log,
+						char *response);
 
 // cater for the (Amazon ALB) use case that only a single EC(!) key is served
 // from the URL
